package org.jboss.seam.example.chatter.action;

import java.io.Serializable;
import java.util.Date;
import java.util.List;
import javax.persistence.EntityManager;
import org.jboss.seam.ScopeType;
import org.jboss.seam.annotations.Factory;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Out;
import org.jboss.seam.annotations.Scope;
import org.jboss.seam.annotations.datamodel.DataModel;
import org.jboss.seam.annotations.security.Restrict;
import org.jboss.seam.international.StatusMessages;
import org.jboss.seam.example.chatter.model.Chatter;
import org.jboss.seam.security.Identity;

@Name("conversationCafe")
@Scope(ScopeType.CONVERSATION)
public class ConversationCafe implements Serializable
{
    @In protected StatusMessages statusMessages;

	@In protected EntityManager entityManager;

	@In protected Identity identity;

	@In @Out(required = false) protected Chatter chatter;

	@Out(required = false) protected Chatter latestChatter;

	@DataModel protected List<Chatter> recentChatter;

	@Restrict(value = "#{identity.loggedIn}")
    public void talk()
    {
		chatter.setUsername(identity.getCredentials().getUsername());
		chatter.setDate(new Date());
		entityManager.persist(chatter);
        statusMessages.add("You're chatter was heard.");
		latestChatter = chatter;
		chatter = null;
		//retrieveRecentChatter();
	}

	@Factory("recentChatter")
	public void retrieveRecentChatter() {
		recentChatter = entityManager.createQuery("select c from Chatter c order by c.date desc").getResultList();
	}

}
